magneticalc.QtWidgets2.QSaveAction.QSaveAction

# ``magneticalc`.`QtWidgets2`.`QSaveAction`.`QSaveAction``

class documentation

`class QSaveAction:`

Constructor: `QSaveAction(gui, title, date, filename, ...)`

View In Hierarchy

QSaveAction class.

Method | `__init__` | Initializes a save dialog.
Instance Variable | `filename` | Undocumented

def __init__(self, gui, title: `str`, date: `bool`, filename: `str`, extension: `str`, _filter: `str`):

Initializes a save dialog.

Parameters
gui | GUI
title: `str` | Title
date: `bool` | Enable datetime prefix
filename: `str` | Filename
extension: `str` | Extension
_filter: `str` | Filename filters

filename =

Undocumented